@@ -83,3 +83,7 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 func (s Scanner) Type() detectorspb.DetectorType {
 	return detectorspb.DetectorType_Autodesk
 }
+
+func (s Scanner) Description() string {
+	return "Autodesk provides software services for design and engineering. Autodesk API keys can be used to access and modify data within Autodesk services."
+}
