@@ -4,10 +4,10 @@ import (
 	"bytes"
 	"context"
 	"encoding/json"
+	"strconv"
 	"strings"
 
 	regexp "github.com/wasilibs/go-re2"
-
 	"golang.org/x/oauth2/google"
 
 	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors"
@@ -17,10 +17,12 @@ import (
 type Scanner struct{}
 
 // Ensure the Scanner satisfies the interface at compile time.
-var _ detectors.Detector = (*Scanner)(nil)
-var _ detectors.CustomFalsePositiveChecker = (*Scanner)(nil)
-var _ detectors.MaxSecretSizeProvider = (*Scanner)(nil)
-var _ detectors.StartOffsetProvider = (*Scanner)(nil)
+var _ interface {
+	detectors.Detector
+	detectors.CustomFalsePositiveChecker
+	detectors.MaxSecretSizeProvider
+	detectors.StartOffsetProvider
+} = (*Scanner)(nil)
 
 var (
 	keyPat = regexp.MustCompile(`\{[^{]+auth_provider_x509_cert_url[^}]+\}`)
@@ -39,12 +41,6 @@ type gcpKey struct {
 	ClientX509CertURL       string `json:"client_x509_cert_url"`
 }
 
-func trimCarrots(s string) string {
-	s = strings.TrimPrefix(s, "<")
-	s = strings.TrimSuffix(s, ">")
-	return s
-}
-
 // Keywords are used for efficiently pre-filtering chunks.
 // Use identifiers in the secret preferably, or the provider name.
 func (s Scanner) Keywords() []string {
@@ -61,22 +57,28 @@ const startOffset = 4096
 // StartOffset returns the start offset for the secret this detector finds.
 func (Scanner) StartOffset() int64 { return startOffset }
 
+func (s Scanner) Type() detectorspb.DetectorType {
+	return detectorspb.DetectorType_GCP
+}
+
+func (s Scanner) Description() string {
+	return "GCP (Google Cloud Platform) is a suite of cloud computing services that runs on the same infrastructure that Google uses internally for its end-user products. GCP keys can be used to access and manage these services."
+}
+
 // FromData will find and optionally verify GCP secrets in a given set of bytes.
 func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (results []detectors.Result, err error) {
 	dataStr := string(data)
 
-	matches := keyPat.FindAllString(dataStr, -1)
+	uniqueMatches := make(map[string]struct{})
+	for _, match := range keyPat.FindAllString(dataStr, -1) {
+		uniqueMatches[match] = struct{}{}
+	}
 
-	for _, match := range matches {
-		key := match
-
-		key = strings.ReplaceAll(key, `,\\n`, `\n`)
-		key = strings.ReplaceAll(key, `\"\\n`, `\n`)
-		key = strings.ReplaceAll(key, `\\"`, `"`)
+	for match := range uniqueMatches {
+		key := cleanInput(match)
 
 		creds := gcpKey{}
-		err := json.Unmarshal([]byte(key), &creds)
-		if err != nil {
+		if err := json.NewDecoder(strings.NewReader(key)).Decode(&creds); err != nil {
 			continue
 		}
 
@@ -84,10 +86,10 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 		if strings.Contains(creds.ClientEmail, `<mailto:`) {
 			creds.ClientEmail = strings.Split(strings.Split(creds.ClientEmail, `<mailto:`)[1], `|`)[0]
 		}
-		creds.AuthProviderX509CertURL = trimCarrots(creds.AuthProviderX509CertURL)
-		creds.AuthURI = trimCarrots(creds.AuthURI)
-		creds.ClientX509CertURL = trimCarrots(creds.ClientX509CertURL)
-		creds.TokenURI = trimCarrots(creds.TokenURI)
+		creds.AuthProviderX509CertURL = trimCarets(creds.AuthProviderX509CertURL)
+		creds.AuthURI = trimCarets(creds.AuthURI)
+		creds.ClientX509CertURL = trimCarets(creds.ClientX509CertURL)
+		creds.TokenURI = trimCarets(creds.TokenURI)
 
 		// Not sure why this might happen, but we've observed this with a verified cred
 		raw := []byte(creds.ClientEmail)
@@ -107,11 +109,10 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 			Raw:          raw,
 			RawV2:        credBytes,
 			Redacted:     creds.ClientEmail,
-		}
-		// Set the RotationGuideURL in the ExtraData
-		result.ExtraData = map[string]string{
-			"rotation_guide": "https://howtorotate.com/docs/tutorials/gcp/",
-			"project":        creds.ProjectID,
+			ExtraData: map[string]string{
+				"rotation_guide": "https://howtorotate.com/docs/tutorials/gcp/",
+				"project":        creds.ProjectID,
+			},
 		}
 
 		if verify {
@@ -119,12 +120,11 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 			if err != nil {
 				continue
 			}
-			if credentials != nil {
-				_, err = credentials.TokenSource.Token()
-				if err == nil {
-					result.Verified = true
-				}
+
+			if _, err = credentials.TokenSource.Token(); err != nil {
+				continue
 			}
+			result.Verified = true
 		}
 
 		results = append(results, result)
@@ -137,10 +137,28 @@ func (s Scanner) IsFalsePositive(_ detectors.Result) (bool, string) {
 	return false, ""
 }
 
-func (s Scanner) Type() detectorspb.DetectorType {
-	return detectorspb.DetectorType_GCP
+// region Helper methods
+func cleanInput(input string) string {
+	input = strings.ReplaceAll(input, `,\\n`, `\n`)
+	input = strings.ReplaceAll(input, `\"\\n`, `\n`)
+	input = strings.ReplaceAll(input, `\\"`, `"`)
+
+	// If the JSON is encoded, it needs to be unquoted for `json.Unmarshal` to succeed.
+	// https://github.com/trufflesecurity/trufflehog/issues/2864
+	if strings.Contains(input, `\"auth_provider_x509_cert_url\"`) {
+		unquoted, err := strconv.Unquote(`"` + input + `"`)
+		if err == nil {
+			return unquoted
+		}
+	}
+
+	return input
 }
 
-func (s Scanner) Description() string {
-	return "GCP (Google Cloud Platform) is a suite of cloud computing services that runs on the same infrastructure that Google uses internally for its end-user products. GCP keys can be used to access and manage these services."
+func trimCarets(s string) string {
+	s = strings.TrimPrefix(s, "<")
+	s = strings.TrimSuffix(s, ">")
+	return s
 }
+
+//endregion
