@@ -102,3 +102,7 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 func (s Scanner) Type() detectorspb.DetectorType {
 	return detectorspb.DetectorType_PortainerToken
 }
+
+func (s Scanner) Description() string {
+	return "Portainer is a management UI for Docker environments. Portainer tokens can be used to authenticate and interact with the Portainer API."
+}
