@@ -72,3 +72,7 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 func (s Scanner) Type() detectorspb.DetectorType {
 	return detectorspb.DetectorType_Salescookie
 }
+
+func (s Scanner) Description() string {
+	return "Salescookie is a sales performance management tool. Salescookie API keys can be used to create and manage transactions within the platform."
+}
