@@ -115,3 +115,7 @@ func verifyTwitch(ctx context.Context, client *http.Client, resMatch string, res
 func (s Scanner) Type() detectorspb.DetectorType {
 	return detectorspb.DetectorType_Twitch
 }
+
+func (s Scanner) Description() string {
+	return "Twitch is a live streaming service. Twitch API keys can be used to access and modify data on the Twitch platform."
+}
