@@ -8,11 +8,12 @@ import (
 
 	"github.com/trufflesecurity/trufflehog/v3/pkg/context"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/pb/sourcespb"
+	"github.com/trufflesecurity/trufflehog/v3/pkg/sources"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/sources/circleci"
 )
 
 // ScanCircleCI scans CircleCI logs.
-func (e *Engine) ScanCircleCI(ctx context.Context, token string) error {
+func (e *Engine) ScanCircleCI(ctx context.Context, token string) (sources.JobProgressRef, error) {
 	connection := &sourcespb.CircleCI{
 		Credential: &sourcespb.CircleCI_Token{
 			Token: token,
@@ -23,7 +24,7 @@ func (e *Engine) ScanCircleCI(ctx context.Context, token string) error {
 	err := anypb.MarshalFrom(&conn, connection, proto.MarshalOptions{})
 	if err != nil {
 		ctx.Logger().Error(err, "failed to marshal Circle CI connection")
-		return err
+		return sources.JobProgressRef{}, err
 	}
 
 	sourceName := "trufflehog - Circle CI"
@@ -31,8 +32,7 @@ func (e *Engine) ScanCircleCI(ctx context.Context, token string) error {
 
 	circleSource := &circleci.Source{}
 	if err := circleSource.Init(ctx, "trufflehog - Circle CI", jobID, sourceID, true, &conn, runtime.NumCPU()); err != nil {
-		return err
+		return sources.JobProgressRef{}, err
 	}
-	_, err = e.sourceManager.Run(ctx, sourceName, circleSource)
-	return err
+	return e.sourceManager.Run(ctx, sourceName, circleSource)
 }
