@@ -14,7 +14,7 @@ import (
 )
 
 // ScanSyslog is a source that scans syslog files.
-func (e *Engine) ScanSyslog(ctx context.Context, c sources.SyslogConfig) error {
+func (e *Engine) ScanSyslog(ctx context.Context, c sources.SyslogConfig) (sources.JobProgressRef, error) {
 	connection := &sourcespb.Syslog{
 		Protocol:      c.Protocol,
 		ListenAddress: c.Address,
@@ -24,13 +24,13 @@ func (e *Engine) ScanSyslog(ctx context.Context, c sources.SyslogConfig) error {
 	if c.CertPath != "" && c.KeyPath != "" {
 		cert, err := os.ReadFile(c.CertPath)
 		if err != nil {
-			return errors.WrapPrefix(err, "could not open TLS cert file", 0)
+			return sources.JobProgressRef{}, errors.WrapPrefix(err, "could not open TLS cert file", 0)
 		}
 		connection.TlsCert = string(cert)
 
 		key, err := os.ReadFile(c.KeyPath)
 		if err != nil {
-			return errors.WrapPrefix(err, "could not open TLS key file", 0)
+			return sources.JobProgressRef{}, errors.WrapPrefix(err, "could not open TLS key file", 0)
 		}
 		connection.TlsKey = string(key)
 	}
@@ -38,17 +38,16 @@ func (e *Engine) ScanSyslog(ctx context.Context, c sources.SyslogConfig) error {
 	var conn anypb.Any
 	err := anypb.MarshalFrom(&conn, connection, proto.MarshalOptions{})
 	if err != nil {
-		return errors.WrapPrefix(err, "error unmarshalling connection", 0)
+		return sources.JobProgressRef{}, errors.WrapPrefix(err, "error unmarshalling connection", 0)
 	}
 
 	sourceName := "trufflehog - syslog"
 	sourceID, jobID, _ := e.sourceManager.GetIDs(ctx, sourceName, syslog.SourceType)
 	syslogSource := &syslog.Source{}
 	if err := syslogSource.Init(ctx, sourceName, jobID, sourceID, true, &conn, c.Concurrency); err != nil {
-		return err
+		return sources.JobProgressRef{}, err
 	}
 	syslogSource.InjectConnection(connection)
 
-	_, err = e.sourceManager.Run(ctx, sourceName, syslogSource)
-	return err
+	return e.sourceManager.Run(ctx, sourceName, syslogSource)
 }
